@@ -27,11 +27,6 @@ class ONTMigrationStatus(enum.Enum):
     cancelled = 'cancelled'
 
 
-class VelopType(enum.Enum):
-    branded = 'branded'
-    unbranded = 'unbranded'
-
-
 class ONT(Base):
     __tablename__ = 'ont'
 
@@ -151,7 +146,6 @@ class ONTMIGRATION(Base):
     migration_status = Column(Enum(ONTMigrationStatus), default='pending')
     sn = Column(String(length=64), nullable=False, comment='ONT SN')
     ont_type = Column(Enum(CPEProvTypeENUM), nullable=False)
-    velop_type = Column(Enum(VelopType))
     old_portid = Column(Integer, nullable=False, comment='OLD DB portid')
     old_slotid = Column(Integer, nullable=False, comment='OLD DB slotid')
     old_frameid = Column(Integer, nullable=False, comment='OLD DB frameid')
@@ -177,13 +171,14 @@ class ONTMIGRATION(Base):
     new_db_record_required = Column(Boolean, default=False, comment='If DB records are required to be created')
     new_db_record_created = Column(Boolean, default=False)
     new_db_record_created_datetime = Column(DateTime)
-    fr_from_tr069_done = Column(Boolean, default=False, comment='Factory reset ONT from TR069 server')
-    fr_from_tr069_datetime = Column(DateTime)
+    fr_done = Column(Boolean, default=False, comment='Factory reset ONT from TR069 server')
+    fr_datetime = Column(DateTime)
     deleted_from_tr069 = Column(Boolean, default=False)
     deleted_from_tr069_datetime = Column(DateTime)
     user = Column(String(length=256), nullable=False, comment='user who requested the swap')
     task_request_datetime = Column(DateTime)
     task_finish_datetime = Column(DateTime)
+    send_notification = Column(Boolean, nullable=False)
     notification_sent_type = Column(String(length=24))
     notification_sent_datetime = Column(DateTime)
     cancel_reason = Column(String(length=256))
